@@ -8,14 +8,19 @@
 
 /* ====== define data types ====== */
 
+typedef struct taf_callback_st taf_callback_t;
+
+struct taf_callback_st {
+	char *function; /*User supplied TAF functiomn*/
+	int  sleep;
+};
+
 typedef struct imp_fbh_st imp_fbh_t;
 
 
 struct imp_drh_st {
 	dbih_drc_t com;		/* MUST be first element in structure	*/
 	OCIEnv *envhp;
-	int proc_handles;		   /* If true, the envhp handle is owned by ProC
-								   and must not be freed. */
 	SV *ora_long;
 	SV *ora_trunc;
 	SV *ora_cache;
@@ -53,6 +58,10 @@ struct imp_dbh_st {
 	char		*driver_name;/*driver name user defined*/
 	ub4			driver_namel;
 #endif
+	taf_callback_t  *taf_callback;
+    bool		using_taf; /*TAF stuff*/
+    char		*taf_function; /*User supplied TAF functiomn*/
+    int			taf_sleep;
     char		*client_info;  /*user defined*/
     ub4			client_infol;
 	char		*module_name; /*module user defined */
@@ -61,8 +70,6 @@ struct imp_dbh_st {
     ub4			client_identifierl;
     char		*action;  /*user defined*/
     ub4			actionl;
-	int proc_handles;		   /* If true, srvhp, svchp, and authp handles
-								   are owned by ProC and must not be freed. */
 	int RowCacheSize; /* both of these are defined by DBI spec*/
 	int RowsInCache;	/* this vaue is RO and cannot be set*/
 	int ph_type;		/* default oratype for placeholders */
@@ -77,6 +84,7 @@ struct imp_dbh_st {
 #define DBH_DUP_LEN (sizeof(struct imp_dbh_st) - sizeof(dbih_dbc_t))
 
 
+
 typedef struct lob_refetch_st lob_refetch_t; /* Define sth implementor data structure */
 
 
@@ -385,6 +393,7 @@ void fb_ary_free(fb_ary_t *fb_ary);
 void rs_array_init(imp_sth_t *imp_sth);
 
 ub4 ora_db_version _((SV *dbh, imp_dbh_t *imp_dbh));
+sb4 reg_taf_callback _((imp_dbh_t *imp_dbh));
 
 /* These defines avoid name clashes for multiple statically linked DBD's	*/
 
